@@ -5,18 +5,10 @@ use Getopt::Long;
 use Text::Fuzzy;
 use Lingua::EN::PluralToSingular 'to_singular';
 
-# The location of the Unix dictionary.
 my $dict = '/usr/share/dict/words';
-
-# Default maximum edit distance. Five is quite a big number for a
-# spelling mistake.
-my $max = 5;
-
 GetOptions (
     "dict=s" => \$dict,
-    "max=i" => \$max,
 );
-
 my @words;
 my %words;
 my $min_length = 4;
@@ -29,11 +21,8 @@ for my $file (@ARGV) {
     while (<$input>) {
         my @line = split /[^a-z']+/i, $_;
         for my $word (@line) {
-	    # Remove leading/trailing apostrophes.
-	    $word =~ s/^'|'$//g;
-	    my $clean_word = to_singular (lc $word);
-	    $clean_word =~ s/'s$//;
-            if ($words{$clean_word} || $words{$word}) {
+            my $clean_word = to_singular (lc $word);
+            if ($words{$clean_word}) {
                 # It is in the dictionary.
                 next;
             }
@@ -49,29 +38,11 @@ for my $file (@ARGV) {
                 # This word was already given to the user.
                 next;
             }
-	    if ($clean_word =~ /(.*)ed$/ || $clean_word =~ /(.*)ing/) {
-		my $stem = $1;
-		if ($words{$stem} || $words{"${stem}e"}) {
-		    # Past/gerund of $stem/${stem}e
-		    next;
-		}
-		# Test for doubled end consonants,
-		# e.g. "submitted"/"submit".
-		if ($stem =~ /([bcdfghjklmnpqrstvwxz])\1/) {
-		    $stem =~ s/$1$//;
-		    if ($words{$stem}) {
-			# Past/gerund of $stem/${stem}e
-			next;
-		    }
-		}
-	    }
-            my $tf = Text::Fuzzy->new ($clean_word, max => $max);
+            my $tf = Text::Fuzzy->new ($clean_word);
             my $nearest = $tf->nearest (\@words);
-	    # We have set a maximum distance to search for, so we need
-	    # to check whether $nearest is defined.
             if (defined $nearest) {
                 my $correction = $words[$nearest];
-                print "$file:$.: '$word' may be '$correction'.\n";
+                print "$file:$.: '$word' may be $correction.\n";
                 $known{$clean_word} = $correction;
             }
             else {
@@ -89,24 +60,10 @@ sub read_dictionary
 {
     my ($dict, $words_array, $words_hash) = @_;    
     open my $din, "<", $dict or die "Can't open dictionary $dict: $!";
-    my @words;
     while (<$din>) {
         chomp;
-	push @words, $_;
-    }
-    close $din or die $!;
-    # Apostrophe words
-
-    my @apo = qw/let's can't I'll he's don't you're I've it's one's
-		 isn't aren't doesn't won't wouldn't we're/;
-
-    # Irregular past participles.
-    my @pp = qw/became/;
-
-    push @words, @apo, @pp;
-    for (@words) {
         push @$words_array, lc $_;
         $words_hash->{$_} = 1;
-        $words_hash->{lc $_} = 1;
     }
+    close $din or die $!;
 }
